# $Id: suphp.spec 3469 2005-08-11 22:23:52Z dag $
# Authority: dag

%define real_name suphp

Summary: Apache module that enables running PHP scripts under different users
Name: mod_suphp
Version: 0.7.1
Release: 0BX11
License: GPL/Apache License
Group: System Environment/Daemons
URL: http://www.suphp.org/

Packager: Michael Stauber <mstauber@blueonyx.it>
Vendor: Team BlueOnyx, http://www.blueonyx.it/

Source: http://projects.marsching.org/suphp/download/suphp-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: httpd-devel >= 2.0, gcc-c++, automake, autoconf, apr-devel
Requires: httpd >= 2.0, php

%description
The suPHP Apache module together with suPHP itself provides an easy way to
run PHP scripts with different users on the same server. It provides security,
because the PHP scripts are not run with the rights of the webserver's user.
In addition to that you probably won't have to use PHP's "safe mode", which
applies many restrictions on the scripts.

%prep
%setup -n %{real_name}-%{version}

%{__cat} <<EOF >suphp.conf
[global]
logfile=/var/log/httpd/suphp_log
loglevel=info
webserver_user=apache
docroot=/
env_path=/bin:/usr/bin:/usr
umask=0022
min_uid=501
min_gid=500

; Security options
allow_file_group_writeable=true
allow_file_others_writeable=false
allow_directory_group_writeable=true
allow_directory_others_writeable=false

;Check wheter script is within DOCUMENT_ROOT
check_vhost_docroot=true

;Send minor error messages to browser
errors_to_browser=true

[handlers]
;Handler for php-scripts
x-httpd-suphp="php:/usr/bin/php-cgi"

;Handler for CGI-scripts
x-suphp-cgi="execute:!self"
EOF

%{__cat} <<EOF >suphp.log
/var/log/httpd/suphp_log {
    missingok 
    notifempty   
    sharedscripts
    postrotate
        /bin/kill -HUP `cat /var/run/httpd.pid 2>/dev/null` 2> /dev/null || true
    endscript
} 
EOF

%{__cat} <<EOF >suphp.httpd
# This is the Apache server configuration file providing suPHP support.
# It contains the configuration directives to instruct the server how to
# serve php pages while switching to the user context before rendering.

LoadModule suphp_module modules/mod_suphp.so

# This option tells mod_suphp if a PHP-script requested on this server (or
# VirtualHost) should be run with the PHP-interpreter or returned to the
# browser "as it is".
suPHP_Engine off

# Disable php when suphp is used, to avoid having both.
#<IfModule mod_php5.c>
#php_admin_flag engine off
#</IfModule>
#<IfModule mod_php4.c>
#php_admin_flag engine off
#</IfModule>

# To use suPHP to parse PHP-Files
#AddHandler x-httpd-php .php
#AddHandler x-httpd-php .php .php5 .php4 .php3 .phtml

# This option tells mod_suphp which path to pass on to the PHP-interpreter
# (by setting the PHPRC environment variable).
# Do *NOT* refer to a file but to the directory the file resides in.
#
# E.g.: If you want to use "/path/to/server/config/php.ini", use "suPHP_Config
# /path/to/server/config".
#
# If you don't use this option, PHP will use its compiled in default path.
# suPHP_ConfigPath /etc

# If you compiled suphp with setid-mode "force" or "paranoid", you can
# specify the user- and groupname to run PHP-scripts with.
# Example: suPHP_UserGroup foouser bargroup
# suPHP_UserGroup apache apache

# This option tells mod_suphp to handle requests with the type <mime-type>.
# Please note this only works, if an action for the handler is specified
# in the suPHP configuration file.
# suPHP_AddHandler x-httpd-php

# This option tells mod_suphp to NOT handle requests with the type <mime-type>.
# suPHP_RemoveHandler <mime-type>
EOF

%build
#export CPPFLAGS="-I/usr/include/apr-0 -I/usr/include/apr-1"
%configure \
	--disable-checkpath \
	--prefix=/usr/ \
	--with-apr=/usr/bin/apr-1-config \
	--with-apache-user="apache" \
	--with-apxs="%{_sbindir}/apxs" \
	--with-logfile="%{_localstatedir}/log/httpd/suphp_log" \
	--with-min-uid="501" \
	--with-min-gid="500" \
	--with-php="%{_bindir}/php-cgi" \
	--with-setid-mode="owner" \
	--enable-SUPHP_USE_USERGROUP=yes
#	--with-setid-mode="paranoid"
%{__make} %{?_smp_mflags} clean all

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR="%{buildroot}"

%{__install} -Dp -m0644 suphp.conf %{buildroot}%{_sysconfdir}/suphp.conf
%{__install} -Dp -m0644 suphp.httpd %{buildroot}%{_sysconfdir}/httpd/conf.d/suphp.conf
%{__install} -Dp -m0644 suphp.log %{buildroot}%{_sysconfdir}/logrotate.d/suphp

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc AUTHORS ChangeLog COPYING doc/ NEWS README
%config(noreplace) %{_sysconfdir}/suphp.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/suphp.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/suphp
%{_libdir}/httpd/modules/mod_suphp.so
%{_sbindir}/suphp

%post
/usr/bin/perl -pi -e 's|^umask=0077|umask=0022|g' /etc/suphp.conf
/usr/sausalito/constructor/base/vsite/import_php_ini_settings.pl || :
/etc/init.d/httpd reload &>/dev/null || :
/bin/chmod 777 /var/lib/php/session

%postun
/usr/sausalito/constructor/base/vsite/import_php_ini_settings.pl || :
/etc/init.d/httpd reload &>/dev/null || :
/etc/init.d/httpd reload &>/dev/null || :

%changelog

* Thu Aug 30 2012 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX11
- Extended suphp-0.7.1/src/Application.cpp error message with notice about 'Web Ownership'.

* Sun Jul 24 2011 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX10
- Config norplace makes it necessary to run a search and replace on /etc/suphp.conf as well.

* Sun Jul 24 2011 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX09
- Changed umask in /etc/suphp.conf from 077 to 022.

* Mon Jul 05 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX08
- Added logrotate for suPHP
- PHP session directory needs to be world writeable if we run php-cgi

* Sun Jul 04 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX07
- Removed handler for an optional third party PHP
- Was a stupid idea as it would need changes in three different modules.
- Third party PHP installs must instead modify /etc/suphp.conf instead, which is much easier.

* Sun Jul 04 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX06
- Added handler for an optional third party PHP
- This is necessary as suPHP will otherwise always use the onboard PHP

* Sun Jul 04 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX05
- Changed 'errors_to_browser' to 'true' in /etc/suphp.conf
- While this may lead to an information disclosure, it also makes sure that site and server admins see why their site doesn't run anymore.
- So this is - for now - an acceptable drawback.

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX04
- Apache restart added to post-install and post-uninstall

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX03
- More tweaks:
- Minimum user ID is now 501, so that scripts owned by 'admin' are not executed for security reasons.
- Since suPHP-0.7.0 handler definitions in /etc/suphp.conf must be escaped with double-ticks
- We use /usr/bin/php-cgi as handler for PHP if suPHP is enabled
- Switched from paranoid to owner and use --enable-SUPHP_USE_USERGROUP=yes as well
- Commented out all unneeded definitions from /etc/httpd/conf.d/suphp.conf as we use all relevant options in the VHost containers

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX02
- General option tweaking

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX01
- Updated to release 0.7.1
